@@ -4,7 +4,7 @@
 #include "structmember.h"
 #include "tags.h"
 
-
+
 // Constructors and destructors //////////////////////////////////////////////
 
 static int
@@ -138,7 +138,21 @@ CBORTag_richcompare(PyObject *aobj, PyObject *bobj, int op)
     return ret;
 }
 
-
+
+static Py_hash_t
+CBORTag_hash(CBORTagObject *self)
+{
+    PyObject *tmp = Py_BuildValue("(iO)", self->tag, self->value);
+    if(!tmp){
+        PyErr_NoMemory();
+        return -1;
+    }
+    Py_hash_t ret = PyObject_Hash(tmp);
+    Py_DECREF(tmp);
+    return ret;
+}
+
+
 // C API /////////////////////////////////////////////////////////////////////
 
 PyObject *
@@ -174,7 +188,7 @@ CBORTag_SetValue(PyObject *tag, PyObject *value)
     return 0;
 }
 
-
+
 // Tag class definition //////////////////////////////////////////////////////
 
 static PyMemberDef CBORTag_members[] = {
@@ -205,5 +219,6 @@ PyTypeObject CBORTagType = {
     .tp_clear = (inquiry) CBORTag_clear,
     .tp_members = CBORTag_members,
     .tp_repr = (reprfunc) CBORTag_repr,
+    .tp_hash = (hashfunc) CBORTag_hash,
     .tp_richcompare = CBORTag_richcompare,
 };
